@@ -8,6 +8,9 @@ ebic.fbed.glmm.ordinal.reps <- function(y, x, id, reps = NULL, univ = NULL, gam
   sela <- NULL
   card <- 0
   
+  zevar <- Rfast::check_data(x)
+  if ( sum( zevar > 0 ) > 0 )  x[, zevar] <- rnorm( n * length(zevar) )
+  
   if ( is.null(gam) ) {
     con <- 2 - log(p) / log(n)
   } else  con <- 2 * gam
@@ -21,6 +24,7 @@ ebic.fbed.glmm.ordinal.reps <- function(y, x, id, reps = NULL, univ = NULL, gam
       fit2 <- ordinal::clmm( y ~ x[, i] + reps + (1|id), weights = wei ) 
       lik2[i] <- BIC(fit2) + con * log(p)
     }
+    lik2[zevar] <- Inf
     n.tests <- p
     stat <- lik1 - lik2
     univ <- list()
@@ -28,6 +32,7 @@ ebic.fbed.glmm.ordinal.reps <- function(y, x, id, reps = NULL, univ = NULL, gam
   } else {
     n.tests <- 0
     lik2 <- univ$ebic
+    lik2[zevar] <- Inf
     stat <- lik1 - lik2
   }  
   s <- which(stat > 0)
@@ -63,11 +68,11 @@ ebic.fbed.glmm.ordinal.reps <- function(y, x, id, reps = NULL, univ = NULL, gam
     
     if (K == 1) {
       M <- length(sela) + 1
-      for ( i in ind[-sela] )  {
+      for ( i in ind[-c(sela, zevar)] )  {
         fit2 <- ordinal::clmm( y ~ x[, c(sela, i)] + reps + (1|id), weights = wei )
         lik2[i] <- BIC(fit2) + con * lchoose(p, M)
       }
-      n.tests[2] <- length( ind[-sela] )
+      n.tests[2] <- length( ind[-c(sela, zevar)] )
       stat <- lik1 - lik2
       s <- which(stat > 0) 
       sel <- which.max(stat) * ( length(s)>0 )
@@ -101,11 +106,11 @@ ebic.fbed.glmm.ordinal.reps <- function(y, x, id, reps = NULL, univ = NULL, gam
     
     if ( K > 1) {
       M <- length(sela) + 1
-      for ( i in ind[-sela] )  {
+      for ( i in ind[-c(sela, zevar)] )  {
         fit2 <- ordinal::clmm( y ~ x[, c(sela, i)] + reps + (1|id), weights = wei )
         lik2[i] <- BIC(fit2) + con * lchoose(p, M)
       }
-      n.tests[2] <- length(ind[-sela])
+      n.tests[2] <- length(ind[-c(sela, zevar)])
       stat <- lik1 - lik2
       s <- which(stat > 0) 
       sel <- which.max(stat) * ( length(s)>0 )
@@ -140,11 +145,11 @@ ebic.fbed.glmm.ordinal.reps <- function(y, x, id, reps = NULL, univ = NULL, gam
       while ( vim < K  & card[vim + 1] - card[vim] > 0 ) {
         vim <- vim + 1
         M <- length(sela) + 1
-        for ( i in ind[-sela] )  {
+        for ( i in ind[-c(sela, zevar)] )  {
           fit2 <- ordinal::clmm( y ~ x[, c(sela, i)] + reps + (1|id), weights = wei )
           lik2[i] <- BIC(fit2) + con * lchoose(p, M)
         }
-        n.tests[vim + 1] <- length(ind[-sela])
+        n.tests[vim + 1] <- length(ind[-c(sela, zevar)])
         stat <- lik1 - lik2
         s <- which(stat > 0)
         sel <- which.max(stat) * ( length(s)>0 )
