@@ -63,7 +63,7 @@ ebic.glmm.ordinal.bsreg <- function(target, dataset, id, wei = NULL, gam = NULL)
           
           i <- 2  
           
-          if ( tool[2] > 0 ) {
+          if ( tool[2] != 0 ) {
             
             while ( tool[i - 1] - tool[i ] > 0  &  NCOL(dat) > 0 )  {   
               
